# Security Policy

## Supported Versions

The following versions are curently supported and will receive patches.

| Version | Supported          |
| ------- | ------------------ |
| 1.1.x   | :white_check_mark: |
| 1.0.x   | :white_check_mark: |
| 0.x.x   | :x:                |

## Reporting a Vulnerability

Report vulnerabilities to isak@wildboar.dev or as GitHub issues.
